/*
	Copyright (C) 2002 Sebastiano Vigna

	This program is free software; you can redistribute it and/or modify it
	under the terms of the GNU General Public License as published by the
	Free Software Foundation; either version 2, or (at your option) any
	later version.
	
	This program is distributed in the hope that it will be useful, but
	WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
	General Public License for more details.
	
	You should have received a copy of the GNU General Public License along
	with this program; see the file COPYING.  If not, write to the Free
	Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
	02111-1307, USA.  


	This is lifekeeper 1.1.

	This program emits a NUL character every few seconds. If you run it in the
	background, it will prevent firewalls watching for activity along a TCP connection
	from shutting it down (thus keeping it alive 8^).

*/

#include <stdio.h>
#include <unistd.h>

#define DEFAULT_INTERVAL 30
#define VERSION "1.1"

int main(int argc, char *argv[]) {
	int secs = 0;

	/* We don't use getopt to keep it as small and simple as possible. */

	if (argc == 2 && !strcmp(argv[1], "-h")) {
		fprintf(stderr, "%s [-h] [-s interval]\nPrints an ASCII NUL character every 30 (or interval) seconds.\n", argv[0]);
		exit(0);
	}

	if (argc == 3 && (strcmp(argv[1], "-s") || !(secs = atoi(argv[2]))) || argc != 1 && !secs) {
		fprintf(stderr, "Wrong parameters\n");
		exit(1);
	}
	
	if (!secs) secs = DEFAULT_INTERVAL;

	for(;;) {
		sleep(secs);
		putchar(0);
		fflush(stdout);

		/* When your parent dies, you get init's PID as parent PID. */
		if (getppid() == 1) exit(0);
	}
}
